"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _assertThisInitialized2 = _interopRequireDefault(require("@babel/runtime/helpers/assertThisInitialized"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime/helpers/inherits"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime/helpers/possibleConstructorReturn"));

var _getPrototypeOf2 = _interopRequireDefault(require("@babel/runtime/helpers/getPrototypeOf"));

var _pick2 = _interopRequireDefault(require("lodash/pick"));

var _isFunction2 = _interopRequireDefault(require("lodash/isFunction"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react2 = _interopRequireDefault(require("auto-bind/react"));

var _reactBootstrap = require("react-bootstrap");

var _reactDropzone = _interopRequireDefault(require("react-dropzone"));

var _classnames = _interopRequireDefault(require("classnames"));

var _loader = require("../loader");

var _imagePreview = _interopRequireDefault(require("../image-preview"));

var _errors = require("./errors");

var _image = require("./image");

require("./style.scss");

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0, _getPrototypeOf2["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0, _getPrototypeOf2["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0, _possibleConstructorReturn2["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var ACCEPT_TYPES = {
  ANY: 'image/*',
  JPG: 'image/jpg',
  JPEG: 'image/jpeg',
  PNG: 'image/png'
};

function shouldCheckImageType(type) {
  return type !== ACCEPT_TYPES.ANY;
}

var ImageUploader = /*#__PURE__*/function (_React$Component) {
  (0, _inherits2["default"])(ImageUploader, _React$Component);

  var _super = _createSuper(ImageUploader);

  function ImageUploader(props) {
    var _this;

    (0, _classCallCheck2["default"])(this, ImageUploader);
    _this = _super.call(this, props);
    (0, _react2["default"])((0, _assertThisInitialized2["default"])(_this));
    _this.state = {
      uploading: false,
      error: null
    };
    return _this;
  }

  (0, _createClass2["default"])(ImageUploader, [{
    key: "handleUploadFailed",
    value: function handleUploadFailed(errorMessage) {
      this.setState({
        error: errorMessage,
        uploading: false
      });
      this.props.onError(errorMessage);
    }
  }, {
    key: "handleUploadSucceeded",
    value: function handleUploadSucceeded(imageUrl) {
      var _this$props = this.props,
          id = _this$props.id,
          onUploadSuccess = _this$props.onUploadSuccess;
      this.setState({
        uploading: false
      });

      if ((0, _isFunction2["default"])(onUploadSuccess)) {
        onUploadSuccess(imageUrl, id);
      }
    }
  }, {
    key: "handleDeleteSucceeded",
    value: function handleDeleteSucceeded(imageUrl) {
      var _this$props2 = this.props,
          id = _this$props2.id,
          onDeleteSuccess = _this$props2.onDeleteSuccess;
      this.setState({
        uploading: false
      });

      if ((0, _isFunction2["default"])(onDeleteSuccess)) {
        onDeleteSuccess(imageUrl, id);
      }
    }
  }, {
    key: "handleDeleteFailed",
    value: function handleDeleteFailed(errorMessage) {
      this.setState({
        error: errorMessage
      });
    }
  }, {
    key: "validateDimensions",
    value: function validateDimensions(image) {
      var dimensionOptions = (0, _pick2["default"])(this.props, ['autoResize', 'width', 'height', 'maxWidth', 'maxHeight', 'minWidth', 'minHeight']);
      return (0, _image.validateImageDimensions)(image, dimensionOptions);
    }
  }, {
    key: "validateFileSize",
    value: function validateFileSize(file) {
      var maxImageSize = this.props.maxImageSize;

      if (file.size > maxImageSize) {
        return (0, _errors.imageSizeTooBigError)(maxImageSize);
      }

      return null;
    }
  }, {
    key: "resizeImage",
    value: function resizeImage(imageElement, imageFile) {
      var resizeOptions = (0, _pick2["default"])(this.props, ['autoResize', 'width', 'height', 'maxWidth', 'maxHeight']);
      var shouldResize = (0, _image.shouldResizeImage)(imageElement, resizeOptions);

      if (!shouldResize) {
        return imageFile;
      }

      var calculateOptions = (0, _pick2["default"])(this.props, ['width', 'height']);

      var _calculateValidImageD = (0, _image.calculateValidImageDimensions)(imageElement, calculateOptions),
          width = _calculateValidImageD.width,
          height = _calculateValidImageD.height;

      var resizedImageFile = (0, _image.resizeImage)(imageElement, width, height, imageFile.name, imageFile.type);
      return resizedImageFile;
    }
  }, {
    key: "upload",
    value: function upload(imageFile) {
      var _this2 = this;

      var _this$props3 = this.props,
          assetManager = _this$props3.assetManager,
          folderName = _this$props3.folderName,
          resolveFilename = _this$props3.resolveFilename;
      var url = URL.createObjectURL(imageFile);
      var imageElement = new Image();
      return new Promise(function (resolve, reject) {
        var fileSizeError = _this2.validateFileSize(imageFile);

        if (fileSizeError) {
          reject(fileSizeError);
          return;
        }

        imageElement.onload = function () {
          var imageDimensionsError = _this2.validateDimensions(imageElement);

          if (imageDimensionsError) {
            reject(imageDimensionsError);
            return;
          }

          var resizedImageFile = _this2.resizeImage(imageElement, imageFile);

          var resolvedFilename = resolveFilename(resizedImageFile);
          var resolvedFolderPath = folderName ? "".concat(folderName, "/") : '';
          var resolvedPath = resolvedFolderPath + resolvedFilename;
          assetManager.uploadFile(resolvedPath, resizedImageFile).then(resolve, function () {
            return reject((0, _errors.imageUploadError)());
          });
        }; // this LOC serves to trigger imageElement.onload function (to validate and upload new image)


        imageElement.src = url;
      });
    }
  }, {
    key: "handleDrop",
    value: function handleDrop(files) {
      var _this$props4 = this.props,
          acceptType = _this$props4.acceptType,
          onError = _this$props4.onError;

      if (files && files.length > 0) {
        this.setState({
          uploading: true,
          error: null
        });
        var currentFile = files[0];

        if (shouldCheckImageType(acceptType) && currentFile.type !== acceptType) {
          this.setState({
            uploading: false
          });
          return onError((0, _errors.imageUploadInvalidType)());
        }

        this.upload(currentFile).then(this.handleUploadSucceeded, this.handleUploadFailed);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props5 = this.props,
          className = _this$props5.className,
          icon = _this$props5.icon,
          previewSize = _this$props5.previewSize,
          preview = _this$props5.preview,
          showValidationError = _this$props5.showValidationError,
          helpText = _this$props5.helpText,
          assetManager = _this$props5.assetManager,
          canBeDeleted = _this$props5.canBeDeleted;
      var classes = (0, _classnames["default"])(className, 'image-uploader__loader', "image-uploader__".concat(previewSize));
      return /*#__PURE__*/_react["default"].createElement(_loader.LoaderContainer, {
        isLoading: this.state.uploading,
        className: classes
      }, /*#__PURE__*/_react["default"].createElement(_reactDropzone["default"], {
        className: "image-uploader__dropzone",
        onDrop: this.handleDrop,
        multiple: false,
        accept: "image/*"
      }, /*#__PURE__*/_react["default"].createElement(_imagePreview["default"], {
        src: preview,
        previewSize: previewSize,
        icon: icon,
        assetManager: assetManager,
        canBeDeleted: canBeDeleted,
        onDeleteSuccess: this.handleDeleteSucceeded,
        onDeleteError: this.handleDeleteFailed,
        showDeleteError: false
      })), showValidationError && this.state.error && /*#__PURE__*/_react["default"].createElement("div", {
        className: "text-error"
      }, this.state.error), helpText && !this.state.error && /*#__PURE__*/_react["default"].createElement(_reactBootstrap.HelpBlock, null, helpText));
    }
  }]);
  return ImageUploader;
}(_react["default"].Component);

exports["default"] = ImageUploader;
ImageUploader.propTypes = {
  /**
   * Object containing methods for uploading, listing, and deleting files on cloud
   */
  assetManager: _propTypes["default"].shape({
    deleteFile: _propTypes["default"].func.isRequired,
    uploadFile: _propTypes["default"].func.isRequired,
    listFolder: _propTypes["default"].func.isRequired
  }).isRequired,

  /**
   * Path where to upload file
   */
  folderName: _propTypes["default"].string.isRequired,

  /**
   *  Callback invoked when image is uploaded
   */
  onUploadSuccess: _propTypes["default"].func.isRequired,

  /**
   * Accepted image type, used when checking image type
   */
  acceptType: _propTypes["default"].string,

  /**
   * Flag indicating whether image should automatically be resized if it's not in correct dimensions
   */
  autoResize: _propTypes["default"].bool,

  /**
   * Flag indicating whether image can be deleted
   */
  canBeDeleted: _propTypes["default"].bool,

  /**
   * Additional classes to apply
   */
  className: _propTypes["default"].string,

  /**
   * Expected image height in pixels
   */
  height: _propTypes["default"].number,

  /**
   * Help text positioned below dropzone
   */
  helpText: _propTypes["default"].string,

  /**
   * FontIcon name (add-photo, add...)
   */
  icon: _propTypes["default"].string,

  /**
   *  Id of the image
   */
  id: _propTypes["default"].string,

  /**
   * Min allowed image height in pixels
   */
  minHeight: _propTypes["default"].number,

  /**
   * Min allowed image width in pixels
   */
  minWidth: _propTypes["default"].number,

  /**
   * Max allowed image size in bytes
   */
  maxImageSize: _propTypes["default"].number,

  /**
   * Max allowed image height in pixels
   */
  maxHeight: _propTypes["default"].number,

  /**
   * Max allowed image width in pixels
   */
  maxWidth: _propTypes["default"].number,

  /**
   * Url to the preview image
   */
  preview: _propTypes["default"].string,

  /**
   * Passed on as a prop to the ImagePreview component,
   * determines image preview block dimensions
   */
  previewSize: _propTypes["default"].string,

  /**
   * Customize your file name before the upload
   */
  resolveFilename: _propTypes["default"].func,

  /**
   * Flag indicating whether to show validation error in component.
   * If set to false, onError function should be provided for displaying upload error.
   */
  showValidationError: _propTypes["default"].bool,

  /**
   * Expected image width in pixels
   */
  width: _propTypes["default"].number,

  /**
   * Callback invoked when upload fails
   */
  onError: _propTypes["default"].func,

  /**
   *  Callback forwarded to ImagePreview component; invoked when existing image is deleted
   */
  onDeleteSuccess: _propTypes["default"].func
};
ImageUploader.defaultProps = {
  acceptType: ACCEPT_TYPES.ANY,
  autoResize: true,
  canBeDeleted: true,
  icon: 'add',
  maxImageSize: 10000000,
  previewSize: 'small',
  resolveFilename: function resolveFilename(file) {
    return file.name;
  },
  showValidationError: true,
  onError: function onError() {}
};