"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = NodeDraggableSource;

var _reactDnd = require("react-dnd");

var _dnd = require("./dnd");

var nodeSource = {
  canDrag: function canDrag(props) {
    return props.isDraggable;
  },
  beginDrag: function beginDrag(props) {
    var source = {
      index: props.index,
      id: props.item.id,
      parentId: props.parentId,
      beginDragIndex: props.index,
      beginDragId: props.item.id,
      beginDragParentId: props.parentId
    };
    props.onDragAndDropStart(source);
    return source;
  },
  endDrag: function endDrag(props, monitor) {
    var node = monitor.getItem();
    var dropResult = monitor.getDropResult();
    var source = {
      index: node.beginDragIndex,
      id: node.beginDragId,
      parentId: node.beginDragParentId
    };
    var target = {
      index: node.index,
      id: node.id,
      parentId: node.parentId
    }; // Return dragged node to original place if drop is not available/accessible

    if (!dropResult || !dropResult.doesParentAllowDrop) {
      (0, _dnd.returnNodeToSource)(props, node, source, target);
      return;
    }

    props.onDragAndDropComplete(source, target);
  },
  isDragging: function isDragging(props, monitor) {
    return props.item.id === monitor.getItem().id;
  }
};

var connectSource = function connectSource(connect, monitor) {
  return {
    connectDragSource: connect.dragSource(),
    connectDragPreview: connect.dragPreview(),
    isDragging: monitor.isDragging()
  };
};

function NodeDraggableSource() {
  return new _reactDnd.DragSource(_dnd.types.NODE, nodeSource, connectSource);
}