"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = NodeDraggableTarget;

var _isUndefined2 = _interopRequireDefault(require("lodash/isUndefined"));

var _reactDnd = require("react-dnd");

var _dnd = require("./dnd");

var nodeTarget = {
  drop: function drop(props, monitor) {
    if (monitor.didDrop()) {
      return undefined;
    }

    return {
      index: props.index,
      id: props.item.id,
      parentId: props.parentId,
      isCollapsed: props.isCollapsed(props.item.id),
      doesParentAllowDrop: props.doesParentAllowDrop,
      isNestable: props.isNestable
    };
  },
  hover: function hover(props, monitor, component) {
    var node = monitor.getItem();
    var dragIndex = node.index;
    var dragId = node.id;
    var dragParentId = node.parentId;
    var hoverIndex = props.index;
    var hoverId = props.item.id;
    var hoverParentId = props.parentId;
    var doesParentAllowDrop = props.doesParentAllowDrop;
    var doesAllowDrop = props.item.doesAllowDrop; // Don't look for every target container, only first, non-greedy

    var isOverCurrent = monitor.isOver({
      shallow: true
    });

    if (!isOverCurrent) {
      return;
    } // don't allow drop if doesAllowDrop is false
    // as we are unable to set doesAllowDrop to be true by default
    // we need to check if isUndefined as we are reacting only on "false"


    if (!(0, _isUndefined2["default"])(doesAllowDrop) && !doesAllowDrop) {
      return;
    } // Ignore if parent doesn't allow dropping of children


    if (!doesParentAllowDrop) {
      return;
    } // Don't allow interaction if dragged items is parent of hovered item


    if (dragId === hoverParentId) {
      return;
    } // Don't replace items with themselves, check only for horizontal change of node level


    if (dragId === hoverId) {
      var levelChange = (0, _dnd.detectSecondaryMovement)(props, monitor, component);

      if (levelChange === 0) {
        return;
      }

      var destination = props.move(dragParentId, dragIndex, hoverParentId, hoverIndex, levelChange);
      (0, _dnd.updateNodeLocation)(node, destination);
      return;
    }

    var isVerticalMovement = (0, _dnd.detectPrimaryMovement)(props, monitor, component);

    if (isVerticalMovement) {
      var _destination = props.move(dragParentId, dragIndex, hoverParentId, hoverIndex);

      (0, _dnd.updateNodeLocation)(node, _destination);
    }
  }
};

var connectTarget = function connectTarget(connect) {
  return {
    connectDropTarget: connect.dropTarget()
  };
};

function NodeDraggableTarget() {
  return new _reactDnd.DropTarget(_dnd.types.NODE, nodeTarget, connectTarget);
}